@@ -29,6 +29,7 @@ v_partition_interval    bigint;
 v_partition_created     boolean := false;
 v_partition_name        text;
 v_partition_type        text;
+v_publications          text[];
 v_revoke                text;
 v_row                   record;
 v_sql                   text;
@@ -51,12 +52,14 @@ SELECT control
     , inherit_fk
     , jobmon
     , template_table
+    , publications
 INTO v_control
     , v_partition_type
     , v_partition_interval
     , v_inherit_fk
     , v_jobmon
     , v_template_table
+    , v_publications
 FROM @extschema@.part_config
 WHERE parent_table = p_parent_table;
 
@@ -159,11 +162,7 @@ FOREACH v_id IN ARRAY p_partition_ids LOOP
     END IF;
     EXECUTE v_sql;
 
-    IF v_parent_tablespace IS NOT NULL THEN
-        EXECUTE format('ALTER TABLE %I.%I SET TABLESPACE %I', v_parent_schema, v_partition_name, v_parent_tablespace);
-    END IF;
-
-    IF v_partition_type = 'native' THEN
+        IF v_partition_type = 'native' THEN
 
         IF v_template_table IS NOT NULL THEN
             PERFORM @extschema@.inherit_template_properties(p_parent_table, v_parent_schema, v_partition_name);
@@ -178,6 +177,10 @@ FOREACH v_id IN ARRAY p_partition_ids LOOP
             , v_id + v_partition_interval);
 
     ELSE
+        -- Handled in inherit_template_properties for native because CREATE TABLE ignores TABLESPACE flag for native partition parents
+        IF v_parent_tablespace IS NOT NULL THEN
+            EXECUTE format('ALTER TABLE %I.%I SET TABLESPACE %I', v_parent_schema, v_partition_name, v_parent_tablespace);
+        END IF;
 
         EXECUTE format('ALTER TABLE %I.%I ADD CONSTRAINT %I CHECK (%I >= %s AND %I < %s )'
             , v_parent_schema
@@ -193,7 +196,7 @@ FOREACH v_id IN ARRAY p_partition_ids LOOP
         -- Indexes cannot be created on the parent, so clustering cannot be used for native yet.
         PERFORM @extschema@.apply_cluster(v_parent_schema, v_parent_tablename, v_parent_schema, v_partition_name);
 
-        -- Foreign keys to other tables not supported in native
+        -- Foreign keys to other tables not supported on native parent tables
         IF v_inherit_fk THEN
             PERFORM @extschema@.apply_foreign_keys(p_parent_table, v_parent_schema||'.'||v_partition_name, v_job_id);
         END IF;
@@ -279,6 +282,11 @@ FOREACH v_id IN ARRAY p_partition_ids LOOP
     -- Manage additonal constraints if set
     PERFORM @extschema@.apply_constraints(p_parent_table, p_job_id := v_job_id, p_debug := p_debug);
 
+    IF v_publications IS NOT NULL THEN
+        -- NOTE: Publications currently not supported on parent table, but are supported on the table partitions if individually assigned.
+        PERFORM @extschema@.apply_publications(p_parent_table, v_parent_schema, v_partition_name);
+    END IF;
+
     v_partition_created := true;
 
 END LOOP;
@@ -333,4 +341,3 @@ HINT: %', ex_message, ex_context, ex_detail, ex_hint;
 END
 $$;
 
-
