@@ -23,8 +23,10 @@ CREATE TABLE part_config (
     , upsert text NOT NULL DEFAULT ''
     , trigger_return_null boolean NOT NULL DEFAULT true
     , template_table text
+    , publications text[]
     , CONSTRAINT part_config_parent_table_pkey PRIMARY KEY (parent_table)
     , CONSTRAINT positive_premake_check CHECK (premake > 0)
+    , CONSTRAINT publications_no_empty_set_chk CHECK (publications <> '{}')
 );
 CREATE INDEX part_config_type_idx ON @extschema@.part_config (partition_type);
 SELECT pg_catalog.pg_extension_config_dump('part_config', '');
@@ -63,6 +65,9 @@ SELECT pg_catalog.pg_extension_config_dump('part_config_sub', '');
 ALTER TABLE @extschema@.part_config ADD CONSTRAINT control_constraint_col_chk CHECK ((constraint_cols @> ARRAY[control]) <> true);
 ALTER TABLE @extschema@.part_config_sub ADD CONSTRAINT control_constraint_col_chk CHECK ((sub_constraint_cols @> ARRAY[sub_control]) <> true);
 
+ALTER TABLE @extschema@.part_config ADD CONSTRAINT retention_schema_not_empty_chk CHECK (retention_schema <> '');
+ALTER TABLE @extschema@.part_config_sub ADD CONSTRAINT retention_schema_not_empty_chk CHECK (sub_retention_schema <> '');
+
 CREATE TABLE custom_time_partitions (
     parent_table text NOT NULL
     , child_table text NOT NULL
@@ -101,7 +106,7 @@ CREATE OR REPLACE VIEW @extschema@.table_privs AS
                OR grantee.rolname = 'PUBLIC' );
 
 
--- Put constraint functions & definitions here because having them separate makes the ordering of their creation harder to control. Some require the above tables to exist first.
+-- Put constraint functions & definitions here because having them in a separate file makes the ordering of their creation harder to control. Some require the above tables to exist first.
 
 /* 
  * Check for valid config values for automatic maintenance
